# Autogenerated by nbdev

d = { 'settings': { 'audience': 'Developers',
                'author': 'João Nogueira',
                'author_email': 'joao.nogueira@datarisk.io',
                'branch': 'main',
                'copyright': 'Put your copyright info here',
                'custom_sidebar': 'False',
                'description': '',
                'dev_requirements': 'jupyter twine',
                'doc_baseurl': '/meoinfo/',
                'doc_host': 'https://joaopcnogueira.github.io',
                'doc_path': '_docs',
                'git_url': 'https://github.com/joaopcnogueira/meoinfo/',
                'host': 'github',
                'keywords': 'nbdev',
                'language': 'English',
                'lib_name': 'meoinfo',
                'lib_path': 'meoinfo',
                'license': 'apache2',
                'min_python': '3.8',
                'nbs_path': 'nbs',
                'recursive': 'False',
                'repo': 'meoinfo',
                'requirements': 'fastcore pandas',
                'status': '2',
                'title': 'meoinfo',
                'tst_flags': 'notest',
                'user': 'joaopcnogueira',
                'version': '0.0.4'},
  'syms': {'meoinfo.core': {'meoinfo.core.Meoinfo': 'https://joaopcnogueira.github.io/meoinfo/core.html#meoinfo'}}}